# Modeling: Process (Meta Model v3)
### On this page
  * [Fundamentals](https://help.sap.com/docs/leanix/ea/process-modeling-v3#fundamentals)
  * [Further options for modeling Processes](https://help.sap.com/docs/leanix/ea/process-modeling-v3#further-options-for-modeling-processes)


In this section, you will find best practices for modeling processes.
